<?php

return [
    'Names' => [
        'af' => 'ఆఫ్రికాన్స్',
        'af_NA' => 'ఆఫ్రికాన్స్ (నమీబియా)',
        'af_ZA' => 'ఆఫ్రికాన్స్ (దక్షిణ ఆఫ్రికా)',
        'ak' => 'అకాన్',
        'ak_GH' => 'అకాన్ (ఘనా)',
        'am' => 'అమ్హారిక్',
        'am_ET' => 'అమ్హారిక్ (ఇథియోపియా)',
        'ar' => 'అరబిక్',
        'ar_001' => 'అరబిక్ (ప్రపంచం)',
        'ar_AE' => 'అరబిక్ (యునైటెడ్ అరబ్ ఎమిరేట్స్)',
        'ar_BH' => 'అరబిక్ (బహ్రెయిన్)',
        'ar_DJ' => 'అరబిక్ (జిబౌటి)',
        'ar_DZ' => 'అరబిక్ (అల్జీరియా)',
        'ar_EG' => 'అరబిక్ (ఈజిప్ట్)',
        'ar_EH' => 'అరబిక్ (పడమటి సహారా)',
        'ar_ER' => 'అరబిక్ (ఎరిట్రియా)',
        'ar_IL' => 'అరబిక్ (ఇజ్రాయెల్)',
        'ar_IQ' => 'అరబిక్ (ఇరాక్)',
        'ar_JO' => 'అరబిక్ (జోర్డాన్)',
        'ar_KM' => 'అరబిక్ (కొమొరోస్)',
        'ar_KW' => 'అరబిక్ (కువైట్)',
        'ar_LB' => 'అరబిక్ (లెబనాన్)',
        'ar_LY' => 'అరబిక్ (లిబియా)',
        'ar_MA' => 'అరబిక్ (మొరాకో)',
        'ar_MR' => 'అరబిక్ (మారిటేనియా)',
        'ar_OM' => 'అరబిక్ (ఓమన్)',
        'ar_PS' => 'అరబిక్ (పాలస్తీనియన్ ప్రాంతాలు)',
        'ar_QA' => 'అరబిక్ (ఖతార్)',
        'ar_SA' => 'అరబిక్ (సౌదీ అరేబియా)',
        'ar_SD' => 'అరబిక్ (సూడాన్)',
        'ar_SO' => 'అరబిక్ (సోమాలియా)',
        'ar_SS' => 'అరబిక్ (దక్షిణ సూడాన్)',
        'ar_SY' => 'అరబిక్ (సిరియా)',
        'ar_TD' => 'అరబిక్ (చాద్)',
        'ar_TN' => 'అరబిక్ (ట్యునీషియా)',
        'ar_YE' => 'అరబిక్ (యెమెన్)',
        'as' => 'అస్సామీస్',
        'as_IN' => 'అస్సామీస్ (భారతదేశం)',
        'az' => 'అజర్బైజాని',
        'az_AZ' => 'అజర్బైజాని (అజర్బైజాన్)',
        'az_Cyrl' => 'అజర్బైజాని (సిరిలిక్)',
        'az_Cyrl_AZ' => 'అజర్బైజాని (సిరిలిక్, అజర్బైజాన్)',
        'az_Latn' => 'అజర్బైజాని (లాటిన్)',
        'az_Latn_AZ' => 'అజర్బైజాని (లాటిన్, అజర్బైజాన్)',
        'ba' => 'బాష్కిర్',
        'ba_RU' => 'బాష్కిర్ (రష్యా)',
        'be' => 'బెలారుషియన్',
        'be_BY' => 'బెలారుషియన్ (బెలారస్)',
        'bg' => 'బల్గేరియన్',
        'bg_BG' => 'బల్గేరియన్ (బల్గేరియా)',
        'bm' => 'బంబారా',
        'bm_ML' => 'బంబారా (మాలి)',
        'bn' => 'బంగ్లా',
        'bn_BD' => 'బంగ్లా (బంగ్లాదేశ్)',
        'bn_IN' => 'బంగ్లా (భారతదేశం)',
        'bo' => 'టిబెటన్',
        'bo_CN' => 'టిబెటన్ (చైనా)',
        'bo_IN' => 'టిబెటన్ (భారతదేశం)',
        'br' => 'బ్రెటన్',
        'br_FR' => 'బ్రెటన్ (ఫ్రాన్స్‌)',
        'bs' => 'బోస్నియన్',
        'bs_BA' => 'బోస్నియన్ (బోస్నియా & హెర్జిగోవినా)',
        'bs_Cyrl' => 'బోస్నియన్ (సిరిలిక్)',
        'bs_Cyrl_BA' => 'బోస్నియన్ (సిరిలిక్, బోస్నియా & హెర్జిగోవినా)',
        'bs_Latn' => 'బోస్నియన్ (లాటిన్)',
        'bs_Latn_BA' => 'బోస్నియన్ (లాటిన్, బోస్నియా & హెర్జిగోవినా)',
        'ca' => 'కాటలాన్',
        'ca_AD' => 'కాటలాన్ (ఆండోరా)',
        'ca_ES' => 'కాటలాన్ (స్పెయిన్)',
        'ca_FR' => 'కాటలాన్ (ఫ్రాన్స్‌)',
        'ca_IT' => 'కాటలాన్ (ఇటలీ)',
        'ce' => 'చెచెన్',
        'ce_RU' => 'చెచెన్ (రష్యా)',
        'cs' => 'చెక్',
        'cs_CZ' => 'చెక్ (చెకియా)',
        'cv' => 'చువాష్',
        'cv_RU' => 'చువాష్ (రష్యా)',
        'cy' => 'వెల్ష్',
        'cy_GB' => 'వెల్ష్ (యునైటెడ్ కింగ్‌డమ్)',
        'da' => 'డానిష్',
        'da_DK' => 'డానిష్ (డెన్మార్క్)',
        'da_GL' => 'డానిష్ (గ్రీన్‌ల్యాండ్)',
        'de' => 'జర్మన్',
        'de_AT' => 'జర్మన్ (ఆస్ట్రియా)',
        'de_BE' => 'జర్మన్ (బెల్జియం)',
        'de_CH' => 'జర్మన్ (స్విట్జర్లాండ్)',
        'de_DE' => 'జర్మన్ (జర్మనీ)',
        'de_IT' => 'జర్మన్ (ఇటలీ)',
        'de_LI' => 'జర్మన్ (లిక్టెన్‌స్టెయిన్)',
        'de_LU' => 'జర్మన్ (లక్సెంబర్గ్)',
        'dz' => 'జోంఖా',
        'dz_BT' => 'జోంఖా (భూటాన్)',
        'ee' => 'యూ',
        'ee_GH' => 'యూ (ఘనా)',
        'ee_TG' => 'యూ (టోగో)',
        'el' => 'గ్రీక్',
        'el_CY' => 'గ్రీక్ (సైప్రస్)',
        'el_GR' => 'గ్రీక్ (గ్రీస్)',
        'en' => 'ఇంగ్లీష్',
        'en_001' => 'ఇంగ్లీష్ (ప్రపంచం)',
        'en_150' => 'ఇంగ్లీష్ (యూరప్)',
        'en_AE' => 'ఇంగ్లీష్ (యునైటెడ్ అరబ్ ఎమిరేట్స్)',
        'en_AG' => 'ఇంగ్లీష్ (ఆంటిగ్వా & బార్బుడా)',
        'en_AI' => 'ఇంగ్లీష్ (ఆంగ్విల్లా)',
        'en_AS' => 'ఇంగ్లీష్ (అమెరికన్ సమోవా)',
        'en_AT' => 'ఇంగ్లీష్ (ఆస్ట్రియా)',
        'en_AU' => 'ఇంగ్లీష్ (ఆస్ట్రేలియా)',
        'en_BB' => 'ఇంగ్లీష్ (బార్బడోస్)',
        'en_BE' => 'ఇంగ్లీష్ (బెల్జియం)',
        'en_BI' => 'ఇంగ్లీష్ (బురుండి)',
        'en_BM' => 'ఇంగ్లీష్ (బెర్ముడా)',
        'en_BS' => 'ఇంగ్లీష్ (బహామాస్)',
        'en_BW' => 'ఇంగ్లీష్ (బోట్స్వానా)',
        'en_BZ' => 'ఇంగ్లీష్ (బెలిజ్)',
        'en_CA' => 'ఇంగ్లీష్ (కెనడా)',
        'en_CC' => 'ఇంగ్లీష్ (కోకోస్ [కీలింగ్] దీవులు)',
        'en_CH' => 'ఇంగ్లీష్ (స్విట్జర్లాండ్)',
        'en_CK' => 'ఇంగ్లీష్ (కుక్ దీవులు)',
        'en_CM' => 'ఇంగ్లీష్ (కామెరూన్)',
        'en_CX' => 'ఇంగ్లీష్ (క్రిస్మస్ దీవి)',
        'en_CY' => 'ఇంగ్లీష్ (సైప్రస్)',
        'en_CZ' => 'ఇంగ్లీష్ (చెకియా)',
        'en_DE' => 'ఇంగ్లీష్ (జర్మనీ)',
        'en_DK' => 'ఇంగ్లీష్ (డెన్మార్క్)',
        'en_DM' => 'ఇంగ్లీష్ (డొమినికా)',
        'en_EE' => 'ఇంగ్లీష్ (ఎస్టోనియా)',
        'en_ER' => 'ఇంగ్లీష్ (ఎరిట్రియా)',
        'en_ES' => 'ఇంగ్లీష్ (స్పెయిన్)',
        'en_FI' => 'ఇంగ్లీష్ (ఫిన్లాండ్)',
        'en_FJ' => 'ఇంగ్లీష్ (ఫిజీ)',
        'en_FK' => 'ఇంగ్లీష్ (ఫాక్‌ల్యాండ్ దీవులు)',
        'en_FM' => 'ఇంగ్లీష్ (మైక్రోనేషియా)',
        'en_FR' => 'ఇంగ్లీష్ (ఫ్రాన్స్‌)',
        'en_GB' => 'ఇంగ్లీష్ (యునైటెడ్ కింగ్‌డమ్)',
        'en_GD' => 'ఇంగ్లీష్ (గ్రెనడా)',
        'en_GE' => 'ఇంగ్లీష్ (జార్జియా)',
        'en_GG' => 'ఇంగ్లీష్ (గర్న్‌సీ)',
        'en_GH' => 'ఇంగ్లీష్ (ఘనా)',
        'en_GI' => 'ఇంగ్లీష్ (జిబ్రాల్టర్)',
        'en_GM' => 'ఇంగ్లీష్ (గాంబియా)',
        'en_GS' => 'ఇంగ్లీష్ (దక్షిణ జార్జియా మరియు దక్షిణ శాండ్విచ్ దీవులు)',
        'en_GU' => 'ఇంగ్లీష్ (గ్వామ్)',
        'en_GY' => 'ఇంగ్లీష్ (గయానా)',
        'en_HK' => 'ఇంగ్లీష్ (హాంకాంగ్ SAR చైనా)',
        'en_HU' => 'ఇంగ్లీష్ (హంగేరీ)',
        'en_ID' => 'ఇంగ్లీష్ (ఇండోనేషియా)',
        'en_IE' => 'ఇంగ్లీష్ (ఐర్లాండ్)',
        'en_IL' => 'ఇంగ్లీష్ (ఇజ్రాయెల్)',
        'en_IM' => 'ఇంగ్లీష్ (ఐల్ ఆఫ్ మాన్)',
        'en_IN' => 'ఇంగ్లీష్ (భారతదేశం)',
        'en_IO' => 'ఇంగ్లీష్ (బ్రిటిష్ హిందూ మహాసముద్ర ప్రాంతం)',
        'en_IT' => 'ఇంగ్లీష్ (ఇటలీ)',
        'en_JE' => 'ఇంగ్లీష్ (జెర్సీ)',
        'en_JM' => 'ఇంగ్లీష్ (జమైకా)',
        'en_JP' => 'ఇంగ్లీష్ (జపాన్)',
        'en_KE' => 'ఇంగ్లీష్ (కెన్యా)',
        'en_KI' => 'ఇంగ్లీష్ (కిరిబాటి)',
        'en_KN' => 'ఇంగ్లీష్ (సెయింట్ కిట్స్ & నెవిస్)',
        'en_KY' => 'ఇంగ్లీష్ (కేమాన్ దీవులు)',
        'en_LC' => 'ఇంగ్లీష్ (సెయింట్ లూసియా)',
        'en_LR' => 'ఇంగ్లీష్ (లైబీరియా)',
        'en_LS' => 'ఇంగ్లీష్ (లెసోతో)',
        'en_LT' => 'ఇంగ్లీష్ (లిథువేనియా)',
        'en_LV' => 'ఇంగ్లీష్ (లాత్వియా)',
        'en_MG' => 'ఇంగ్లీష్ (మడగాస్కర్)',
        'en_MH' => 'ఇంగ్లీష్ (మార్షల్ దీవులు)',
        'en_MO' => 'ఇంగ్లీష్ (మకావ్ SAR చైనా)',
        'en_MP' => 'ఇంగ్లీష్ (ఉత్తర మరియానా దీవులు)',
        'en_MS' => 'ఇంగ్లీష్ (మాంట్సెరాట్)',
        'en_MT' => 'ఇంగ్లీష్ (మాల్టా)',
        'en_MU' => 'ఇంగ్లీష్ (మారిషస్)',
        'en_MV' => 'ఇంగ్లీష్ (మాల్దీవులు)',
        'en_MW' => 'ఇంగ్లీష్ (మలావీ)',
        'en_MY' => 'ఇంగ్లీష్ (మలేషియా)',
        'en_NA' => 'ఇంగ్లీష్ (నమీబియా)',
        'en_NF' => 'ఇంగ్లీష్ (నార్ఫోక్ దీవి)',
        'en_NG' => 'ఇంగ్లీష్ (నైజీరియా)',
        'en_NL' => 'ఇంగ్లీష్ (నెదర్లాండ్స్)',
        'en_NO' => 'ఇంగ్లీష్ (నార్వే)',
        'en_NR' => 'ఇంగ్లీష్ (నౌరు)',
        'en_NU' => 'ఇంగ్లీష్ (నియూ)',
        'en_NZ' => 'ఇంగ్లీష్ (న్యూజిలాండ్)',
        'en_PG' => 'ఇంగ్లీష్ (పాపువా న్యూ గినియా)',
        'en_PH' => 'ఇంగ్లీష్ (ఫిలిప్పైన్స్)',
        'en_PK' => 'ఇంగ్లీష్ (పాకిస్తాన్)',
        'en_PL' => 'ఇంగ్లీష్ (పోలాండ్)',
        'en_PN' => 'ఇంగ్లీష్ (పిట్‌కెయిర్న్ దీవులు)',
        'en_PR' => 'ఇంగ్లీష్ (ప్యూర్టో రికో)',
        'en_PT' => 'ఇంగ్లీష్ (పోర్చుగల్)',
        'en_PW' => 'ఇంగ్లీష్ (పాలావ్)',
        'en_RO' => 'ఇంగ్లీష్ (రోమేనియా)',
        'en_RW' => 'ఇంగ్లీష్ (రువాండా)',
        'en_SB' => 'ఇంగ్లీష్ (సోలమన్ దీవులు)',
        'en_SC' => 'ఇంగ్లీష్ (సీషెల్స్)',
        'en_SD' => 'ఇంగ్లీష్ (సూడాన్)',
        'en_SE' => 'ఇంగ్లీష్ (స్వీడన్)',
        'en_SG' => 'ఇంగ్లీష్ (సింగపూర్)',
        'en_SH' => 'ఇంగ్లీష్ (సెయింట్ హెలెనా)',
        'en_SI' => 'ఇంగ్లీష్ (స్లోవేనియా)',
        'en_SK' => 'ఇంగ్లీష్ (స్లొవేకియా)',
        'en_SL' => 'ఇంగ్లీష్ (సియెర్రా లియాన్)',
        'en_SS' => 'ఇంగ్లీష్ (దక్షిణ సూడాన్)',
        'en_SX' => 'ఇంగ్లీష్ (సింట్ మార్టెన్)',
        'en_SZ' => 'ఇంగ్లీష్ (ఈస్వాటిని)',
        'en_TC' => 'ఇంగ్లీష్ (టర్క్స్ & కైకోస్ దీవులు)',
        'en_TK' => 'ఇంగ్లీష్ (టోకెలావ్)',
        'en_TO' => 'ఇంగ్లీష్ (టోంగా)',
        'en_TT' => 'ఇంగ్లీష్ (ట్రినిడాడ్ మరియు టొబాగో)',
        'en_TV' => 'ఇంగ్లీష్ (టువాలు)',
        'en_TZ' => 'ఇంగ్లీష్ (టాంజానియా)',
        'en_UA' => 'ఇంగ్లీష్ (ఉక్రెయిన్)',
        'en_UG' => 'ఇంగ్లీష్ (ఉగాండా)',
        'en_UM' => 'ఇంగ్లీష్ (U.S. బయట ఉన్న దీవులు)',
        'en_US' => 'ఇంగ్లీష్ (యునైటెడ్ స్టేట్స్)',
        'en_VC' => 'ఇంగ్లీష్ (సెయింట్ విన్సెంట్ మరియు గ్రెనడీన్స్)',
        'en_VG' => 'ఇంగ్లీష్ (బ్రిటిష్ వర్జిన్ దీవులు)',
        'en_VI' => 'ఇంగ్లీష్ (యు.ఎస్. వర్జిన్ దీవులు)',
        'en_VU' => 'ఇంగ్లీష్ (వనాటు)',
        'en_WS' => 'ఇంగ్లీష్ (సమోవా)',
        'en_ZA' => 'ఇంగ్లీష్ (దక్షిణ ఆఫ్రికా)',
        'en_ZM' => 'ఇంగ్లీష్ (జాంబియా)',
        'en_ZW' => 'ఇంగ్లీష్ (జింబాబ్వే)',
        'eo' => 'ఎస్పెరాంటో',
        'eo_001' => 'ఎస్పెరాంటో (ప్రపంచం)',
        'es' => 'స్పానిష్',
        'es_419' => 'స్పానిష్ (లాటిన్ అమెరికా)',
        'es_AR' => 'స్పానిష్ (అర్జెంటీనా)',
        'es_BO' => 'స్పానిష్ (బొలీవియా)',
        'es_BR' => 'స్పానిష్ (బ్రెజిల్)',
        'es_BZ' => 'స్పానిష్ (బెలిజ్)',
        'es_CL' => 'స్పానిష్ (చిలీ)',
        'es_CO' => 'స్పానిష్ (కొలంబియా)',
        'es_CR' => 'స్పానిష్ (కోస్టా రికా)',
        'es_CU' => 'స్పానిష్ (క్యూబా)',
        'es_DO' => 'స్పానిష్ (డొమినికన్ రిపబ్లిక్)',
        'es_EC' => 'స్పానిష్ (ఈక్వడార్)',
        'es_ES' => 'స్పానిష్ (స్పెయిన్)',
        'es_GQ' => 'స్పానిష్ (ఈక్వటోరియల్ గినియా)',
        'es_GT' => 'స్పానిష్ (గ్వాటిమాలా)',
        'es_HN' => 'స్పానిష్ (హోండురాస్)',
        'es_MX' => 'స్పానిష్ (మెక్సికో)',
        'es_NI' => 'స్పానిష్ (నికరాగువా)',
        'es_PA' => 'స్పానిష్ (పనామా)',
        'es_PE' => 'స్పానిష్ (పెరూ)',
        'es_PH' => 'స్పానిష్ (ఫిలిప్పైన్స్)',
        'es_PR' => 'స్పానిష్ (ప్యూర్టో రికో)',
        'es_PY' => 'స్పానిష్ (పరాగ్వే)',
        'es_SV' => 'స్పానిష్ (ఎల్ సాల్వడోర్)',
        'es_US' => 'స్పానిష్ (యునైటెడ్ స్టేట్స్)',
        'es_UY' => 'స్పానిష్ (ఉరుగ్వే)',
        'es_VE' => 'స్పానిష్ (వెనిజులా)',
        'et' => 'ఎస్టోనియన్',
        'et_EE' => 'ఎస్టోనియన్ (ఎస్టోనియా)',
        'eu' => 'బాస్క్యూ',
        'eu_ES' => 'బాస్క్యూ (స్పెయిన్)',
        'fa' => 'పర్షియన్',
        'fa_AF' => 'పర్షియన్ (ఆఫ్ఘనిస్తాన్)',
        'fa_IR' => 'పర్షియన్ (ఇరాన్)',
        'ff' => 'ఫూలా',
        'ff_Adlm' => 'ఫూలా (అద్లామ్)',
        'ff_Adlm_BF' => 'ఫూలా (అద్లామ్, బుర్కినా ఫాసో)',
        'ff_Adlm_CM' => 'ఫూలా (అద్లామ్, కామెరూన్)',
        'ff_Adlm_GH' => 'ఫూలా (అద్లామ్, ఘనా)',
        'ff_Adlm_GM' => 'ఫూలా (అద్లామ్, గాంబియా)',
        'ff_Adlm_GN' => 'ఫూలా (అద్లామ్, గినియా)',
        'ff_Adlm_GW' => 'ఫూలా (అద్లామ్, గినియా-బిస్సావ్)',
        'ff_Adlm_LR' => 'ఫూలా (అద్లామ్, లైబీరియా)',
        'ff_Adlm_MR' => 'ఫూలా (అద్లామ్, మారిటేనియా)',
        'ff_Adlm_NE' => 'ఫూలా (అద్లామ్, నైజర్)',
        'ff_Adlm_NG' => 'ఫూలా (అద్లామ్, నైజీరియా)',
        'ff_Adlm_SL' => 'ఫూలా (అద్లామ్, సియెర్రా లియాన్)',
        'ff_Adlm_SN' => 'ఫూలా (అద్లామ్, సెనెగల్)',
        'ff_CM' => 'ఫూలా (కామెరూన్)',
        'ff_GN' => 'ఫూలా (గినియా)',
        'ff_Latn' => 'ఫూలా (లాటిన్)',
        'ff_Latn_BF' => 'ఫూలా (లాటిన్, బుర్కినా ఫాసో)',
        'ff_Latn_CM' => 'ఫూలా (లాటిన్, కామెరూన్)',
        'ff_Latn_GH' => 'ఫూలా (లాటిన్, ఘనా)',
        'ff_Latn_GM' => 'ఫూలా (లాటిన్, గాంబియా)',
        'ff_Latn_GN' => 'ఫూలా (లాటిన్, గినియా)',
        'ff_Latn_GW' => 'ఫూలా (లాటిన్, గినియా-బిస్సావ్)',
        'ff_Latn_LR' => 'ఫూలా (లాటిన్, లైబీరియా)',
        'ff_Latn_MR' => 'ఫూలా (లాటిన్, మారిటేనియా)',
        'ff_Latn_NE' => 'ఫూలా (లాటిన్, నైజర్)',
        'ff_Latn_NG' => 'ఫూలా (లాటిన్, నైజీరియా)',
        'ff_Latn_SL' => 'ఫూలా (లాటిన్, సియెర్రా లియాన్)',
        'ff_Latn_SN' => 'ఫూలా (లాటిన్, సెనెగల్)',
        'ff_MR' => 'ఫూలా (మారిటేనియా)',
        'ff_SN' => 'ఫూలా (సెనెగల్)',
        'fi' => 'ఫిన్నిష్',
        'fi_FI' => 'ఫిన్నిష్ (ఫిన్లాండ్)',
        'fo' => 'ఫారోస్',
        'fo_DK' => 'ఫారోస్ (డెన్మార్క్)',
        'fo_FO' => 'ఫారోస్ (ఫారో దీవులు)',
        'fr' => 'ఫ్రెంచ్',
        'fr_BE' => 'ఫ్రెంచ్ (బెల్జియం)',
        'fr_BF' => 'ఫ్రెంచ్ (బుర్కినా ఫాసో)',
        'fr_BI' => 'ఫ్రెంచ్ (బురుండి)',
        'fr_BJ' => 'ఫ్రెంచ్ (బెనిన్)',
        'fr_BL' => 'ఫ్రెంచ్ (సెయింట్ బర్థెలిమి)',
        'fr_CA' => 'ఫ్రెంచ్ (కెనడా)',
        'fr_CD' => 'ఫ్రెంచ్ (కాంగో- కిన్షాసా)',
        'fr_CF' => 'ఫ్రెంచ్ (సెంట్రల్ ఆఫ్రికన్ రిపబ్లిక్)',
        'fr_CG' => 'ఫ్రెంచ్ (కాంగో- బ్రాజావిల్లి)',
        'fr_CH' => 'ఫ్రెంచ్ (స్విట్జర్లాండ్)',
        'fr_CI' => 'ఫ్రెంచ్ (కోట్ డి ఐవోర్)',
        'fr_CM' => 'ఫ్రెంచ్ (కామెరూన్)',
        'fr_DJ' => 'ఫ్రెంచ్ (జిబౌటి)',
        'fr_DZ' => 'ఫ్రెంచ్ (అల్జీరియా)',
        'fr_FR' => 'ఫ్రెంచ్ (ఫ్రాన్స్‌)',
        'fr_GA' => 'ఫ్రెంచ్ (గేబన్)',
        'fr_GF' => 'ఫ్రెంచ్ (ఫ్రెంచ్ గియానా)',
        'fr_GN' => 'ఫ్రెంచ్ (గినియా)',
        'fr_GP' => 'ఫ్రెంచ్ (గ్వాడెలోప్)',
        'fr_GQ' => 'ఫ్రెంచ్ (ఈక్వటోరియల్ గినియా)',
        'fr_HT' => 'ఫ్రెంచ్ (హైతీ)',
        'fr_KM' => 'ఫ్రెంచ్ (కొమొరోస్)',
        'fr_LU' => 'ఫ్రెంచ్ (లక్సెంబర్గ్)',
        'fr_MA' => 'ఫ్రెంచ్ (మొరాకో)',
        'fr_MC' => 'ఫ్రెంచ్ (మొనాకో)',
        'fr_MF' => 'ఫ్రెంచ్ (సెయింట్ మార్టిన్)',
        'fr_MG' => 'ఫ్రెంచ్ (మడగాస్కర్)',
        'fr_ML' => 'ఫ్రెంచ్ (మాలి)',
        'fr_MQ' => 'ఫ్రెంచ్ (మార్టినీక్)',
        'fr_MR' => 'ఫ్రెంచ్ (మారిటేనియా)',
        'fr_MU' => 'ఫ్రెంచ్ (మారిషస్)',
        'fr_NC' => 'ఫ్రెంచ్ (కొత్త కాలెడోనియా)',
        'fr_NE' => 'ఫ్రెంచ్ (నైజర్)',
        'fr_PF' => 'ఫ్రెంచ్ (ఫ్రెంచ్ పోలినీషియా)',
        'fr_PM' => 'ఫ్రెంచ్ (సెయింట్ పియెర్ మరియు మికెలాన్)',
        'fr_RE' => 'ఫ్రెంచ్ (రీయూనియన్)',
        'fr_RW' => 'ఫ్రెంచ్ (రువాండా)',
        'fr_SC' => 'ఫ్రెంచ్ (సీషెల్స్)',
        'fr_SN' => 'ఫ్రెంచ్ (సెనెగల్)',
        'fr_SY' => 'ఫ్రెంచ్ (సిరియా)',
        'fr_TD' => 'ఫ్రెంచ్ (చాద్)',
        'fr_TG' => 'ఫ్రెంచ్ (టోగో)',
        'fr_TN' => 'ఫ్రెంచ్ (ట్యునీషియా)',
        'fr_VU' => 'ఫ్రెంచ్ (వనాటు)',
        'fr_WF' => 'ఫ్రెంచ్ (వాల్లిస్ మరియు ఫుటునా)',
        'fr_YT' => 'ఫ్రెంచ్ (మాయొట్)',
        'fy' => 'పశ్చిమ ఫ్రిసియన్',
        'fy_NL' => 'పశ్చిమ ఫ్రిసియన్ (నెదర్లాండ్స్)',
        'ga' => 'ఐరిష్',
        'ga_GB' => 'ఐరిష్ (యునైటెడ్ కింగ్‌డమ్)',
        'ga_IE' => 'ఐరిష్ (ఐర్లాండ్)',
        'gd' => 'స్కాటిష్ గేలిక్',
        'gd_GB' => 'స్కాటిష్ గేలిక్ (యునైటెడ్ కింగ్‌డమ్)',
        'gl' => 'గాలిషియన్',
        'gl_ES' => 'గాలిషియన్ (స్పెయిన్)',
        'gu' => 'గుజరాతీ',
        'gu_IN' => 'గుజరాతీ (భారతదేశం)',
        'gv' => 'మాంక్స్',
        'gv_IM' => 'మాంక్స్ (ఐల్ ఆఫ్ మాన్)',
        'ha' => 'హౌసా',
        'ha_GH' => 'హౌసా (ఘనా)',
        'ha_NE' => 'హౌసా (నైజర్)',
        'ha_NG' => 'హౌసా (నైజీరియా)',
        'he' => 'హీబ్రూ',
        'he_IL' => 'హీబ్రూ (ఇజ్రాయెల్)',
        'hi' => 'హిందీ',
        'hi_IN' => 'హిందీ (భారతదేశం)',
        'hi_Latn' => 'హిందీ (లాటిన్)',
        'hi_Latn_IN' => 'హిందీ (లాటిన్, భారతదేశం)',
        'hr' => 'క్రొయేషియన్',
        'hr_BA' => 'క్రొయేషియన్ (బోస్నియా & హెర్జిగోవినా)',
        'hr_HR' => 'క్రొయేషియన్ (క్రొయేషియా)',
        'hu' => 'హంగేరియన్',
        'hu_HU' => 'హంగేరియన్ (హంగేరీ)',
        'hy' => 'ఆర్మీనియన్',
        'hy_AM' => 'ఆర్మీనియన్ (ఆర్మేనియా)',
        'ia' => 'ఇంటర్లింగ్వా',
        'ia_001' => 'ఇంటర్లింగ్వా (ప్రపంచం)',
        'id' => 'ఇండోనేషియన్',
        'id_ID' => 'ఇండోనేషియన్ (ఇండోనేషియా)',
        'ie' => 'ఇంటర్లింగ్',
        'ie_EE' => 'ఇంటర్లింగ్ (ఎస్టోనియా)',
        'ig' => 'ఇగ్బో',
        'ig_NG' => 'ఇగ్బో (నైజీరియా)',
        'ii' => 'శిషువన్ ఈ',
        'ii_CN' => 'శిషువన్ ఈ (చైనా)',
        'is' => 'ఐస్లాండిక్',
        'is_IS' => 'ఐస్లాండిక్ (ఐస్లాండ్)',
        'it' => 'ఇటాలియన్',
        'it_CH' => 'ఇటాలియన్ (స్విట్జర్లాండ్)',
        'it_IT' => 'ఇటాలియన్ (ఇటలీ)',
        'it_SM' => 'ఇటాలియన్ (శాన్ మారినో)',
        'it_VA' => 'ఇటాలియన్ (వాటికన్ నగరం)',
        'ja' => 'జపనీస్',
        'ja_JP' => 'జపనీస్ (జపాన్)',
        'jv' => 'జావనీస్',
        'jv_ID' => 'జావనీస్ (ఇండోనేషియా)',
        'ka' => 'జార్జియన్',
        'ka_GE' => 'జార్జియన్ (జార్జియా)',
        'ki' => 'కికుయు',
        'ki_KE' => 'కికుయు (కెన్యా)',
        'kk' => 'కజఖ్',
        'kk_Arab' => 'కజఖ్ (అరబిక్)',
        'kk_Arab_CN' => 'కజఖ్ (అరబిక్, చైనా)',
        'kk_Cyrl' => 'కజఖ్ (సిరిలిక్)',
        'kk_Cyrl_KZ' => 'కజఖ్ (సిరిలిక్, కజకిస్తాన్)',
        'kk_KZ' => 'కజఖ్ (కజకిస్తాన్)',
        'kl' => 'కలాల్లిసూట్',
        'kl_GL' => 'కలాల్లిసూట్ (గ్రీన్‌ల్యాండ్)',
        'km' => 'ఖ్మేర్',
        'km_KH' => 'ఖ్మేర్ (కంబోడియా)',
        'kn' => 'కన్నడ',
        'kn_IN' => 'కన్నడ (భారతదేశం)',
        'ko' => 'కొరియన్',
        'ko_CN' => 'కొరియన్ (చైనా)',
        'ko_KP' => 'కొరియన్ (ఉత్తర కొరియా)',
        'ko_KR' => 'కొరియన్ (దక్షిణ కొరియా)',
        'ks' => 'కాశ్మీరి',
        'ks_Arab' => 'కాశ్మీరి (అరబిక్)',
        'ks_Arab_IN' => 'కాశ్మీరి (అరబిక్, భారతదేశం)',
        'ks_Deva' => 'కాశ్మీరి (దేవనాగరి)',
        'ks_Deva_IN' => 'కాశ్మీరి (దేవనాగరి, భారతదేశం)',
        'ks_IN' => 'కాశ్మీరి (భారతదేశం)',
        'ku' => 'కుర్దిష్',
        'ku_Latn' => 'కుర్దిష్ (లాటిన్)',
        'ku_Latn_IQ' => 'కుర్దిష్ (లాటిన్, ఇరాక్)',
        'ku_Latn_SY' => 'కుర్దిష్ (లాటిన్, సిరియా)',
        'ku_Latn_TR' => 'కుర్దిష్ (లాటిన్, తుర్కియె)',
        'ku_SY' => 'కుర్దిష్ (సిరియా)',
        'ku_TR' => 'కుర్దిష్ (తుర్కియె)',
        'kw' => 'కోర్నిష్',
        'kw_GB' => 'కోర్నిష్ (యునైటెడ్ కింగ్‌డమ్)',
        'ky' => 'కిర్గిజ్',
        'ky_KG' => 'కిర్గిజ్ (కిర్గిజిస్తాన్)',
        'lb' => 'లక్సెంబర్గిష్',
        'lb_LU' => 'లక్సెంబర్గిష్ (లక్సెంబర్గ్)',
        'lg' => 'గాండా',
        'lg_UG' => 'గాండా (ఉగాండా)',
        'ln' => 'లింగాల',
        'ln_AO' => 'లింగాల (అంగోలా)',
        'ln_CD' => 'లింగాల (కాంగో- కిన్షాసా)',
        'ln_CF' => 'లింగాల (సెంట్రల్ ఆఫ్రికన్ రిపబ్లిక్)',
        'ln_CG' => 'లింగాల (కాంగో- బ్రాజావిల్లి)',
        'lo' => 'లావో',
        'lo_LA' => 'లావో (లావోస్)',
        'lt' => 'లిథువేనియన్',
        'lt_LT' => 'లిథువేనియన్ (లిథువేనియా)',
        'lu' => 'లూబ-కటాంగ',
        'lu_CD' => 'లూబ-కటాంగ (కాంగో- కిన్షాసా)',
        'lv' => 'లాట్వియన్',
        'lv_LV' => 'లాట్వియన్ (లాత్వియా)',
        'mg' => 'మలగాసి',
        'mg_MG' => 'మలగాసి (మడగాస్కర్)',
        'mi' => 'మావొరీ',
        'mi_NZ' => 'మావొరీ (న్యూజిలాండ్)',
        'mk' => 'మాసిడోనియన్',
        'mk_MK' => 'మాసిడోనియన్ (ఉత్తర మాసిడోనియా)',
        'ml' => 'మలయాళం',
        'ml_IN' => 'మలయాళం (భారతదేశం)',
        'mn' => 'మంగోలియన్',
        'mn_MN' => 'మంగోలియన్ (మంగోలియా)',
        'mr' => 'మరాఠీ',
        'mr_IN' => 'మరాఠీ (భారతదేశం)',
        'ms' => 'మలయ్',
        'ms_BN' => 'మలయ్ (బ్రూనే)',
        'ms_ID' => 'మలయ్ (ఇండోనేషియా)',
        'ms_MY' => 'మలయ్ (మలేషియా)',
        'ms_SG' => 'మలయ్ (సింగపూర్)',
        'mt' => 'మాల్టీస్',
        'mt_MT' => 'మాల్టీస్ (మాల్టా)',
        'my' => 'బర్మీస్',
        'my_MM' => 'బర్మీస్ (మయన్మార్)',
        'nb' => 'నార్వేజియన్ బొక్మాల్',
        'nb_NO' => 'నార్వేజియన్ బొక్మాల్ (నార్వే)',
        'nb_SJ' => 'నార్వేజియన్ బొక్మాల్ (స్వాల్‌బార్డ్ మరియు జాన్ మాయెన్)',
        'nd' => 'ఉత్తర దెబెలె',
        'nd_ZW' => 'ఉత్తర దెబెలె (జింబాబ్వే)',
        'ne' => 'నేపాలీ',
        'ne_IN' => 'నేపాలీ (భారతదేశం)',
        'ne_NP' => 'నేపాలీ (నేపాల్)',
        'nl' => 'డచ్',
        'nl_AW' => 'డచ్ (అరుబా)',
        'nl_BE' => 'డచ్ (బెల్జియం)',
        'nl_BQ' => 'డచ్ (కరీబియన్ నెదర్లాండ్స్)',
        'nl_CW' => 'డచ్ (క్యూరసో)',
        'nl_NL' => 'డచ్ (నెదర్లాండ్స్)',
        'nl_SR' => 'డచ్ (సూరినామ్)',
        'nl_SX' => 'డచ్ (సింట్ మార్టెన్)',
        'nn' => 'నార్వేజియాన్ న్యోర్స్క్',
        'nn_NO' => 'నార్వేజియాన్ న్యోర్స్క్ (నార్వే)',
        'no' => 'నార్వేజియన్',
        'no_NO' => 'నార్వేజియన్ (నార్వే)',
        'oc' => 'ఆక్సిటన్',
        'oc_ES' => 'ఆక్సిటన్ (స్పెయిన్)',
        'oc_FR' => 'ఆక్సిటన్ (ఫ్రాన్స్‌)',
        'om' => 'ఒరోమో',
        'om_ET' => 'ఒరోమో (ఇథియోపియా)',
        'om_KE' => 'ఒరోమో (కెన్యా)',
        'or' => 'ఒడియా',
        'or_IN' => 'ఒడియా (భారతదేశం)',
        'os' => 'ఒసేటిక్',
        'os_GE' => 'ఒసేటిక్ (జార్జియా)',
        'os_RU' => 'ఒసేటిక్ (రష్యా)',
        'pa' => 'పంజాబీ',
        'pa_Arab' => 'పంజాబీ (అరబిక్)',
        'pa_Arab_PK' => 'పంజాబీ (అరబిక్, పాకిస్తాన్)',
        'pa_Guru' => 'పంజాబీ (గుర్ముఖి)',
        'pa_Guru_IN' => 'పంజాబీ (గుర్ముఖి, భారతదేశం)',
        'pa_IN' => 'పంజాబీ (భారతదేశం)',
        'pa_PK' => 'పంజాబీ (పాకిస్తాన్)',
        'pl' => 'పోలిష్',
        'pl_PL' => 'పోలిష్ (పోలాండ్)',
        'ps' => 'పాష్టో',
        'ps_AF' => 'పాష్టో (ఆఫ్ఘనిస్తాన్)',
        'ps_PK' => 'పాష్టో (పాకిస్తాన్)',
        'pt' => 'పోర్చుగీస్',
        'pt_AO' => 'పోర్చుగీస్ (అంగోలా)',
        'pt_BR' => 'పోర్చుగీస్ (బ్రెజిల్)',
        'pt_CH' => 'పోర్చుగీస్ (స్విట్జర్లాండ్)',
        'pt_CV' => 'పోర్చుగీస్ (కేప్ వెర్డె)',
        'pt_GQ' => 'పోర్చుగీస్ (ఈక్వటోరియల్ గినియా)',
        'pt_GW' => 'పోర్చుగీస్ (గినియా-బిస్సావ్)',
        'pt_LU' => 'పోర్చుగీస్ (లక్సెంబర్గ్)',
        'pt_MO' => 'పోర్చుగీస్ (మకావ్ SAR చైనా)',
        'pt_MZ' => 'పోర్చుగీస్ (మొజాంబిక్)',
        'pt_PT' => 'పోర్చుగీస్ (పోర్చుగల్)',
        'pt_ST' => 'పోర్చుగీస్ (సావో టోమ్ మరియు ప్రిన్సిపి)',
        'pt_TL' => 'పోర్చుగీస్ (టిమోర్-లెస్టె)',
        'qu' => 'కెచువా',
        'qu_BO' => 'కెచువా (బొలీవియా)',
        'qu_EC' => 'కెచువా (ఈక్వడార్)',
        'qu_PE' => 'కెచువా (పెరూ)',
        'rm' => 'రోమన్ష్',
        'rm_CH' => 'రోమన్ష్ (స్విట్జర్లాండ్)',
        'rn' => 'రుండి',
        'rn_BI' => 'రుండి (బురుండి)',
        'ro' => 'రొమేనియన్',
        'ro_MD' => 'రొమేనియన్ (మోల్డోవా)',
        'ro_RO' => 'రొమేనియన్ (రోమేనియా)',
        'ru' => 'రష్యన్',
        'ru_BY' => 'రష్యన్ (బెలారస్)',
        'ru_KG' => 'రష్యన్ (కిర్గిజిస్తాన్)',
        'ru_KZ' => 'రష్యన్ (కజకిస్తాన్)',
        'ru_MD' => 'రష్యన్ (మోల్డోవా)',
        'ru_RU' => 'రష్యన్ (రష్యా)',
        'ru_UA' => 'రష్యన్ (ఉక్రెయిన్)',
        'rw' => 'కిన్యర్వాండా',
        'rw_RW' => 'కిన్యర్వాండా (రువాండా)',
        'sa' => 'సంస్కృతం',
        'sa_IN' => 'సంస్కృతం (భారతదేశం)',
        'sc' => 'సార్డీనియన్',
        'sc_IT' => 'సార్డీనియన్ (ఇటలీ)',
        'sd' => 'సింధీ',
        'sd_Arab' => 'సింధీ (అరబిక్)',
        'sd_Arab_PK' => 'సింధీ (అరబిక్, పాకిస్తాన్)',
        'sd_Deva' => 'సింధీ (దేవనాగరి)',
        'sd_Deva_IN' => 'సింధీ (దేవనాగరి, భారతదేశం)',
        'sd_IN' => 'సింధీ (భారతదేశం)',
        'sd_PK' => 'సింధీ (పాకిస్తాన్)',
        'se' => 'ఉత్తర సామి',
        'se_FI' => 'ఉత్తర సామి (ఫిన్లాండ్)',
        'se_NO' => 'ఉత్తర సామి (నార్వే)',
        'se_SE' => 'ఉత్తర సామి (స్వీడన్)',
        'sg' => 'సాంగో',
        'sg_CF' => 'సాంగో (సెంట్రల్ ఆఫ్రికన్ రిపబ్లిక్)',
        'sh' => 'సేర్బో-క్రొయేషియన్',
        'sh_BA' => 'సేర్బో-క్రొయేషియన్ (బోస్నియా & హెర్జిగోవినా)',
        'si' => 'సింహళం',
        'si_LK' => 'సింహళం (శ్రీలంక)',
        'sk' => 'స్లోవక్',
        'sk_SK' => 'స్లోవక్ (స్లొవేకియా)',
        'sl' => 'స్లోవేనియన్',
        'sl_SI' => 'స్లోవేనియన్ (స్లోవేనియా)',
        'sn' => 'షోన',
        'sn_ZW' => 'షోన (జింబాబ్వే)',
        'so' => 'సోమాలి',
        'so_DJ' => 'సోమాలి (జిబౌటి)',
        'so_ET' => 'సోమాలి (ఇథియోపియా)',
        'so_KE' => 'సోమాలి (కెన్యా)',
        'so_SO' => 'సోమాలి (సోమాలియా)',
        'sq' => 'అల్బేనియన్',
        'sq_AL' => 'అల్బేనియన్ (అల్బేనియా)',
        'sq_MK' => 'అల్బేనియన్ (ఉత్తర మాసిడోనియా)',
        'sr' => 'సెర్బియన్',
        'sr_BA' => 'సెర్బియన్ (బోస్నియా & హెర్జిగోవినా)',
        'sr_Cyrl' => 'సెర్బియన్ (సిరిలిక్)',
        'sr_Cyrl_BA' => 'సెర్బియన్ (సిరిలిక్, బోస్నియా & హెర్జిగోవినా)',
        'sr_Cyrl_ME' => 'సెర్బియన్ (సిరిలిక్, మాంటెనెగ్రో)',
        'sr_Cyrl_RS' => 'సెర్బియన్ (సిరిలిక్, సెర్బియా)',
        'sr_Latn' => 'సెర్బియన్ (లాటిన్)',
        'sr_Latn_BA' => 'సెర్బియన్ (లాటిన్, బోస్నియా & హెర్జిగోవినా)',
        'sr_Latn_ME' => 'సెర్బియన్ (లాటిన్, మాంటెనెగ్రో)',
        'sr_Latn_RS' => 'సెర్బియన్ (లాటిన్, సెర్బియా)',
        'sr_ME' => 'సెర్బియన్ (మాంటెనెగ్రో)',
        'sr_RS' => 'సెర్బియన్ (సెర్బియా)',
        'st' => 'దక్షిణ సోతో',
        'st_LS' => 'దక్షిణ సోతో (లెసోతో)',
        'st_ZA' => 'దక్షిణ సోతో (దక్షిణ ఆఫ్రికా)',
        'su' => 'సండానీస్',
        'su_ID' => 'సండానీస్ (ఇండోనేషియా)',
        'su_Latn' => 'సండానీస్ (లాటిన్)',
        'su_Latn_ID' => 'సండానీస్ (లాటిన్, ఇండోనేషియా)',
        'sv' => 'స్వీడిష్',
        'sv_AX' => 'స్వీడిష్ (ఆలాండ్ దీవులు)',
        'sv_FI' => 'స్వీడిష్ (ఫిన్లాండ్)',
        'sv_SE' => 'స్వీడిష్ (స్వీడన్)',
        'sw' => 'స్వాహిలి',
        'sw_CD' => 'స్వాహిలి (కాంగో- కిన్షాసా)',
        'sw_KE' => 'స్వాహిలి (కెన్యా)',
        'sw_TZ' => 'స్వాహిలి (టాంజానియా)',
        'sw_UG' => 'స్వాహిలి (ఉగాండా)',
        'ta' => 'తమిళం',
        'ta_IN' => 'తమిళం (భారతదేశం)',
        'ta_LK' => 'తమిళం (శ్రీలంక)',
        'ta_MY' => 'తమిళం (మలేషియా)',
        'ta_SG' => 'తమిళం (సింగపూర్)',
        'te' => 'తెలుగు',
        'te_IN' => 'తెలుగు (భారతదేశం)',
        'tg' => 'తజిక్',
        'tg_TJ' => 'తజిక్ (తజికిస్తాన్)',
        'th' => 'థాయ్',
        'th_TH' => 'థాయ్ (థాయిలాండ్)',
        'ti' => 'టిగ్రిన్యా',
        'ti_ER' => 'టిగ్రిన్యా (ఎరిట్రియా)',
        'ti_ET' => 'టిగ్రిన్యా (ఇథియోపియా)',
        'tk' => 'తుర్క్‌మెన్',
        'tk_TM' => 'తుర్క్‌మెన్ (టర్క్‌మెనిస్తాన్)',
        'tl' => 'టగలాగ్',
        'tl_PH' => 'టగలాగ్ (ఫిలిప్పైన్స్)',
        'tn' => 'స్వానా',
        'tn_BW' => 'స్వానా (బోట్స్వానా)',
        'tn_ZA' => 'స్వానా (దక్షిణ ఆఫ్రికా)',
        'to' => 'టాంగాన్',
        'to_TO' => 'టాంగాన్ (టోంగా)',
        'tr' => 'టర్కిష్',
        'tr_CY' => 'టర్కిష్ (సైప్రస్)',
        'tr_TR' => 'టర్కిష్ (తుర్కియె)',
        'tt' => 'టాటర్',
        'tt_RU' => 'టాటర్ (రష్యా)',
        'ug' => 'ఉయ్‌ఘర్',
        'ug_CN' => 'ఉయ్‌ఘర్ (చైనా)',
        'uk' => 'ఉక్రెయినియన్',
        'uk_UA' => 'ఉక్రెయినియన్ (ఉక్రెయిన్)',
        'ur' => 'ఉర్దూ',
        'ur_IN' => 'ఉర్దూ (భారతదేశం)',
        'ur_PK' => 'ఉర్దూ (పాకిస్తాన్)',
        'uz' => 'ఉజ్బెక్',
        'uz_AF' => 'ఉజ్బెక్ (ఆఫ్ఘనిస్తాన్)',
        'uz_Arab' => 'ఉజ్బెక్ (అరబిక్)',
        'uz_Arab_AF' => 'ఉజ్బెక్ (అరబిక్, ఆఫ్ఘనిస్తాన్)',
        'uz_Cyrl' => 'ఉజ్బెక్ (సిరిలిక్)',
        'uz_Cyrl_UZ' => 'ఉజ్బెక్ (సిరిలిక్, ఉజ్బెకిస్తాన్)',
        'uz_Latn' => 'ఉజ్బెక్ (లాటిన్)',
        'uz_Latn_UZ' => 'ఉజ్బెక్ (లాటిన్, ఉజ్బెకిస్తాన్)',
        'uz_UZ' => 'ఉజ్బెక్ (ఉజ్బెకిస్తాన్)',
        'vi' => 'వియత్నామీస్',
        'vi_VN' => 'వియత్నామీస్ (వియత్నాం)',
        'wo' => 'ఉలూఫ్',
        'wo_SN' => 'ఉలూఫ్ (సెనెగల్)',
        'xh' => 'షోసా',
        'xh_ZA' => 'షోసా (దక్షిణ ఆఫ్రికా)',
        'yi' => 'ఇడ్డిష్',
        'yi_UA' => 'ఇడ్డిష్ (ఉక్రెయిన్)',
        'yo' => 'యోరుబా',
        'yo_BJ' => 'యోరుబా (బెనిన్)',
        'yo_NG' => 'యోరుబా (నైజీరియా)',
        'za' => 'జువాన్',
        'za_CN' => 'జువాన్ (చైనా)',
        'zh' => 'చైనీస్',
        'zh_CN' => 'చైనీస్ (చైనా)',
        'zh_HK' => 'చైనీస్ (హాంకాంగ్ SAR చైనా)',
        'zh_Hans' => 'చైనీస్ (సరళీకృతం)',
        'zh_Hans_CN' => 'చైనీస్ (సరళీకృతం, చైనా)',
        'zh_Hans_HK' => 'చైనీస్ (సరళీకృతం, హాంకాంగ్ SAR చైనా)',
        'zh_Hans_MO' => 'చైనీస్ (సరళీకృతం, మకావ్ SAR చైనా)',
        'zh_Hans_MY' => 'చైనీస్ (సరళీకృతం, మలేషియా)',
        'zh_Hans_SG' => 'చైనీస్ (సరళీకృతం, సింగపూర్)',
        'zh_Hant' => 'చైనీస్ (సాంప్రదాయక)',
        'zh_Hant_HK' => 'చైనీస్ (సాంప్రదాయక, హాంకాంగ్ SAR చైనా)',
        'zh_Hant_MO' => 'చైనీస్ (సాంప్రదాయక, మకావ్ SAR చైనా)',
        'zh_Hant_MY' => 'చైనీస్ (సాంప్రదాయక, మలేషియా)',
        'zh_Hant_TW' => 'చైనీస్ (సాంప్రదాయక, తైవాన్)',
        'zh_MO' => 'చైనీస్ (మకావ్ SAR చైనా)',
        'zh_SG' => 'చైనీస్ (సింగపూర్)',
        'zh_TW' => 'చైనీస్ (తైవాన్)',
        'zu' => 'జూలూ',
        'zu_ZA' => 'జూలూ (దక్షిణ ఆఫ్రికా)',
    ],
];
